@@ -3,7 +3,7 @@ from .loading import get_profile
 
 from .decorators import AutoScript, Script, Component, AutoComponent, Modifier, AutoModifier, Modification
 
-from .config import ConfigIter, EmptyElement
+from .config import ConfigIter, EmptyElement, ConfigType
 Component('iter')(ConfigIter)
 del ConfigIter
 
@@ -20,6 +20,7 @@ from .rules import Meta_Rule
 from .modes import Run_Mode
 from . import common
 from .common import Configurable
+from.organization import Cerifiable
 # from .farming import Farmer, Worker
 
 from omnibelt import AbortTransaction
