@@ -17,6 +17,9 @@ class Configurable:
 		if _req_kwargs is unspecified_argument:
 			_req_kwargs = A.pull('_req_kwargs', {}, silent=True)
 
+		# if _req_kwargs is None:
+		# 	_req_kwargs = kwargs
+
 		try:
 			walled = isinstance(self, InitWall)
 		except ValueError:
@@ -25,4 +28,8 @@ class Configurable:
 		if walled:
 			super().__init__(_req_args=_req_args, _req_kwargs=_req_kwargs, **kwargs)
 		else:
-			super().__init__(*_req_args, **_req_kwargs)
+			kwargs.update(_req_kwargs)
+			super().__init__(**kwargs)
+			# super().__init__(*_req_args, **_req_kwargs)
+
+
